
# Type: time


A time object represents a (local) time of day, independent of any particular day

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Time](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Time)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **XSDTime** |
| Representation | | str |
